svn commit: r207331 - head/sys/dev/e1000

Jack F Vogel jfv at FreeBSD.org
Wed Apr 28 17:37:30 UTC 2010


Author: jfv
Date: Wed Apr 28 17:37:30 2010
New Revision: 207331
URL: http://svn.freebsd.org/changeset/base/207331

Log:
  Change default WOL back to MAGIC only, having
  multicast enabled causes problems in man environments.

Modified:
  head/sys/dev/e1000/if_em.c

Modified: head/sys/dev/e1000/if_em.c
==============================================================================
--- head/sys/dev/e1000/if_em.c	Wed Apr 28 17:26:05 2010	(r207330)
+++ head/sys/dev/e1000/if_em.c	Wed Apr 28 17:37:30 2010	(r207331)
@@ -2707,10 +2707,10 @@ em_setup_interface(device_t dev, struct 
 	ifp->if_capabilities |= IFCAP_POLLING;
 #endif
 
 	/* Enable All WOL methods by default */
 	if (adapter->wol) {
 		ifp->if_capabilities |= IFCAP_WOL;
-		ifp->if_capenable |= IFCAP_WOL;
+		ifp->if_capenable |= IFCAP_WOL_MAGIC;
 	}
 		
 	/*
@@ -2707,10 +2707,10 @@ em_setup_interface(device_t dev, struct 
 #endif
 
-	/* Enable All WOL methods by default */
+	/* Enable only WOL MAGIC by default */
 	if (adapter->wol) {
 		ifp->if_capabilities |= IFCAP_WOL;


More information about the svn-src-head mailing list